@@ -66,30 +66,36 @@ int main(int argc, char* argv[]) {
         std::exit(1);
     }
 
-    // The Reader is initialized here with an osmium::io::File, but could
-    // also be directly initialized with a file name.
-    osmium::io::File input_file{argv[1]};
-    osmium::io::Reader reader{input_file};
+    try {
+        // The Reader is initialized here with an osmium::io::File, but could
+        // also be directly initialized with a file name.
+        osmium::io::File input_file{argv[1]};
+        osmium::io::Reader reader{input_file};
 
-    // Create an instance of our own CountHandler and push the data from the
-    // input file through it.
-    CountHandler handler;
-    osmium::apply(reader, handler);
+        // Create an instance of our own CountHandler and push the data from the
+        // input file through it.
+        CountHandler handler;
+        osmium::apply(reader, handler);
 
-    // You do not have to close the Reader explicitly, but because the
-    // destructor can't throw, you will not see any errors otherwise.
-    reader.close();
+        // You do not have to close the Reader explicitly, but because the
+        // destructor can't throw, you will not see any errors otherwise.
+        reader.close();
 
-    std::cout << "Nodes: "     << handler.nodes << "\n";
-    std::cout << "Ways: "      << handler.ways << "\n";
-    std::cout << "Relations: " << handler.relations << "\n";
+        std::cout << "Nodes: "     << handler.nodes << "\n";
+        std::cout << "Ways: "      << handler.ways << "\n";
+        std::cout << "Relations: " << handler.relations << "\n";
 
-    // Because of the huge amount of OSM data, some Osmium-based programs
-    // (though not this one) can use huge amounts of data. So checking actual
-    // memore usage is often useful and can be done easily with this class.
-    // (Currently only works on Linux, not OSX and Windows.)
-    osmium::MemoryUsage memory;
+        // Because of the huge amount of OSM data, some Osmium-based programs
+        // (though not this one) can use huge amounts of data. So checking actual
+        // memore usage is often useful and can be done easily with this class.
+        // (Currently only works on Linux, not OSX and Windows.)
+        osmium::MemoryUsage memory;
 
-    std::cout << "\nMemory used: " << memory.peak() << " MBytes\n";
+        std::cout << "\nMemory used: " << memory.peak() << " MBytes\n";
+    } catch (const std::exception& e) {
+        // All exceptions used by the Osmium library derive from std::exception.
+        std::cerr << e.what() << '\n';
+        std::exit(1);
+    }
 }
 
