@@ -65,30 +65,36 @@ int main(int argc, char* argv[]) {
         std::exit(1);
     }
 
-    const std::string input_filename{argv[1]};
-    const std::string cache_filename{argv[2]};
+    try {
+        const std::string input_filename{argv[1]};
+        const std::string cache_filename{argv[2]};
 
-    // Construct Reader reading only nodes
-    osmium::io::Reader reader{input_filename, osmium::osm_entity_bits::node};
+        // Construct Reader reading only nodes
+        osmium::io::Reader reader{input_filename, osmium::osm_entity_bits::node};
 
-    // Initialize location index on disk creating a new file.
-    const int fd = ::open(cache_filename.c_str(), O_RDWR | O_CREAT | O_TRUNC, 0666); // NOLINT(hicpp-signed-bitwise)
-    if (fd == -1) {
-        std::cerr << "Can not open location cache file '" << cache_filename << "': " << std::strerror(errno) << "\n";
+        // Initialize location index on disk creating a new file.
+        const int fd = ::open(cache_filename.c_str(), O_RDWR | O_CREAT | O_TRUNC, 0666); // NOLINT(hicpp-signed-bitwise)
+        if (fd == -1) {
+            std::cerr << "Can not open location cache file '" << cache_filename << "': " << std::strerror(errno) << "\n";
+            std::exit(1);
+        }
+#ifdef _WIN32
+        _setmode(fd, _O_BINARY);
+#endif
+        index_type index{fd};
+
+        // The handler that stores all node locations in the index.
+        location_handler_type location_handler{index};
+
+        // Feed all nodes through the location handler.
+        osmium::apply(reader, location_handler);
+
+        // Explicitly close input so we get notified of any errors.
+        reader.close();
+    } catch (const std::exception& e) {
+        // All exceptions used by the Osmium library derive from std::exception.
+        std::cerr << e.what() << '\n';
         std::exit(1);
     }
-#ifdef _WIN32
-    _setmode(fd, _O_BINARY);
-#endif
-    index_type index{fd};
-
-    // The handler that stores all node locations in the index.
-    location_handler_type location_handler{index};
-
-    // Feed all nodes through the location handler.
-    osmium::apply(reader, location_handler);
-
-    // Explicitly close input so we get notified of any errors.
-    reader.close();
 }
 
