@@ -1,11 +1,11 @@
 #include "catch.hpp"
 
-#include <random>
-
 #include <osmium/geom/factory.hpp>
 #include <osmium/geom/mercator_projection.hpp>
 #include <osmium/geom/projection.hpp>
 
+#include <random>
+
 TEST_CASE("Indentity Projection") {
     osmium::geom::IdentityProjection projection;
     REQUIRE(4326 == projection.epsg());
@@ -76,53 +76,35 @@ TEST_CASE("Projection 3857") {
     }
 }
 
-TEST_CASE("MercatorProjection") {
+TEST_CASE("MercatorProjection: Zero coordinates") {
     osmium::geom::MercatorProjection projection;
-
-    SECTION("Zero coordinates") {
-        const osmium::Location loc{0.0, 0.0};
-        const osmium::geom::Coordinates c{0.0, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
-    }
-
-    SECTION("Max longitude") {
-        const osmium::Location loc{180.0, 0.0};
-        const osmium::geom::Coordinates c{20037508.34, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
-    }
-
-    SECTION("Min longitude") {
-        const osmium::Location loc{-180.0, 0.0};
-        const osmium::geom::Coordinates c{-20037508.34, 0.0};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
-    }
-
-    SECTION("Max latitude") {
-        const osmium::Location loc{0.0, 85.0511288};
-        const osmium::geom::Coordinates c{0.0, 20037508.34};
-        REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
-        REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
-    }
+    const osmium::Location loc{0.0, 0.0};
+    const osmium::geom::Coordinates c{0.0, 0.0};
+    REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+    REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
 }
 
-TEST_CASE("Compare mercator implementations") {
-    osmium::geom::MercatorProjection projection_merc;
-    osmium::geom::Projection projection_3857{3857};
-
-    SECTION("random coordinates") {
-        std::random_device rd;
-        std::mt19937 gen{rd()};
-        std::uniform_real_distribution<> dis_x{-180.0, 180.0};
-        std::uniform_real_distribution<> dis_y{-90.0, 90.0};
-
-        for (int n = 0; n < 10000; ++n) {
-            const osmium::Location loc{dis_x(gen), dis_y(gen)};
-            REQUIRE(projection_merc(loc).x == Approx(projection_3857(loc).x).epsilon(0.00001));
-            REQUIRE(projection_merc(loc).y == Approx(projection_3857(loc).y).epsilon(0.00001));
-        }
-    }
-
+TEST_CASE("MercatorProjection: Max longitude") {
+    osmium::geom::MercatorProjection projection;
+    const osmium::Location loc{180.0, 0.0};
+    const osmium::geom::Coordinates c{20037508.34, 0.0};
+    REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+    REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
 }
+
+TEST_CASE("MercatorProjection: Min longitude") {
+    osmium::geom::MercatorProjection projection;
+    const osmium::Location loc{-180.0, 0.0};
+    const osmium::geom::Coordinates c{-20037508.34, 0.0};
+    REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+    REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
+}
+
+TEST_CASE("MercatorProjection: Max latitude") {
+    osmium::geom::MercatorProjection projection;
+    const osmium::Location loc{0.0, 85.0511288};
+    const osmium::geom::Coordinates c{0.0, 20037508.34};
+    REQUIRE(projection(loc).x == Approx(c.x).epsilon(0.00001));
+    REQUIRE(projection(loc).y == Approx(c.y).epsilon(0.00001));
+}
+
