@@ -1,10 +1,10 @@
 #include "catch.hpp"
 
-#include <sstream>
+#include "test_tile_data.hpp"
 
 #include <osmium/geom/tile.hpp>
 
-#include "test_tile_data.hpp"
+#include <sstream>
 
 TEST_CASE("Helper functions") {
     REQUIRE(osmium::geom::num_tiles_in_zoom(0) == 1);
@@ -41,7 +41,7 @@ TEST_CASE("Tile from x180.0 y90.0 at zoom 4") {
 
     osmium::geom::Tile t{4, l};
 
-    REQUIRE(t.x == (1 << 4) - 1);
+    REQUIRE(t.x == (1u << 4u) - 1);
     REQUIRE(t.y == 0);
     REQUIRE(t.z == 4);
     REQUIRE(t.valid());
@@ -52,7 +52,7 @@ TEST_CASE("Tile from x0.0 y0.0 at zoom 4") {
 
     osmium::geom::Tile t{4, l};
 
-    const auto n = 1 << (4-1);
+    const auto n = 1u << (4u - 1u);
     REQUIRE(t.x == n);
     REQUIRE(t.y == n);
     REQUIRE(t.z == 4);
@@ -65,7 +65,7 @@ TEST_CASE("Tile from max values at zoom 4") {
 }
 
 TEST_CASE("Tile from max values at zoom 30") {
-    osmium::geom::Tile t{30u, (1u<<30) - 1, (1u<<30) - 1};
+    osmium::geom::Tile t{30u, (1u << 30u) - 1, (1u << 30u) - 1};
     REQUIRE(t.valid());
 }
 
