@@ -44,29 +44,46 @@ struct ZeroPositionNodeCountHandler : public osmium::handler::Handler {
 
 TEST_CASE("Reader can be initialized with file") {
     osmium::io::File file{with_data_dir("t/io/data.osm")};
+
+    const int count = count_fds();
     osmium::io::Reader reader{file};
     osmium::handler::Handler handler;
 
     osmium::apply(reader, handler);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader can be initialized with string") {
+    const int count = count_fds();
+
     osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
     osmium::handler::Handler handler;
 
     osmium::apply(reader, handler);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader can be initialized with user-provided pool") {
+    const int count = count_fds();
+
     osmium::thread::Pool pool{4};
     osmium::io::File file{with_data_dir("t/io/data.osm")};
     osmium::io::Reader reader{file, pool};
     osmium::handler::Handler handler;
 
     osmium::apply(reader, handler);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should throw after eof") {
+    const int count = count_fds();
+
     osmium::io::File file{with_data_dir("t/io/data.osm")};
     osmium::io::Reader reader{file};
 
@@ -87,18 +104,26 @@ TEST_CASE("Reader should throw after eof") {
 
     reader.close();
     REQUIRE(reader.eof());
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should not hang when apply() is called twice on reader") {
+    const int count = count_fds();
+
     osmium::io::File file{with_data_dir("t/io/data.osm")};
     osmium::io::Reader reader{file};
     osmium::handler::Handler handler;
 
     osmium::apply(reader, handler);
     REQUIRE_THROWS_AS(osmium::apply(reader, handler), const osmium::io_error&);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should work with a buffer with uncompressed data") {
+    const int count = count_fds();
+
     const int fd = osmium::io::detail::open_for_reading(with_data_dir("t/io/data.osm"));
     REQUIRE(fd >= 0);
 
@@ -106,6 +131,7 @@ TEST_CASE("Reader should work with a buffer with uncompressed data") {
     char buffer[buffer_size];
     const auto length = ::read(fd, buffer, buffer_size);
     REQUIRE(length > 0);
+    osmium::io::detail::reliable_close(fd);
 
     osmium::io::File file{buffer, static_cast<size_t>(length), "osm"};
     osmium::io::Reader reader{file};
@@ -114,9 +140,14 @@ TEST_CASE("Reader should work with a buffer with uncompressed data") {
     REQUIRE(handler.count == 0);
     osmium::apply(reader, handler);
     REQUIRE(handler.count == 1);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should work with a buffer with gzip-compressed data") {
+    const int count = count_fds();
+
     const int fd = osmium::io::detail::open_for_reading(with_data_dir("t/io/data.osm.gz"));
     REQUIRE(fd >= 0);
 
@@ -124,6 +155,7 @@ TEST_CASE("Reader should work with a buffer with gzip-compressed data") {
     char buffer[buffer_size];
     const auto length = ::read(fd, buffer, buffer_size);
     REQUIRE(length > 0);
+    osmium::io::detail::reliable_close(fd);
 
     osmium::io::File file{buffer, static_cast<size_t>(length), "osm.gz"};
     osmium::io::Reader reader{file};
@@ -132,9 +164,14 @@ TEST_CASE("Reader should work with a buffer with gzip-compressed data") {
     REQUIRE(handler.count == 0);
     osmium::apply(reader, handler);
     REQUIRE(handler.count == 1);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should work with a buffer with bzip2-compressed data") {
+    const int count = count_fds();
+
     const int fd = osmium::io::detail::open_for_reading(with_data_dir("t/io/data.osm.bz2"));
     REQUIRE(fd >= 0);
 
@@ -142,6 +179,7 @@ TEST_CASE("Reader should work with a buffer with bzip2-compressed data") {
     char buffer[buffer_size];
     const auto length = ::read(fd, buffer, buffer_size);
     REQUIRE(length > 0);
+    osmium::io::detail::reliable_close(fd);
 
     osmium::io::File file{buffer, static_cast<size_t>(length), "osm.bz2"};
     osmium::io::Reader reader{file};
@@ -150,9 +188,14 @@ TEST_CASE("Reader should work with a buffer with bzip2-compressed data") {
     REQUIRE(handler.count == 0);
     osmium::apply(reader, handler);
     REQUIRE(handler.count == 1);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should decode zero node positions in history (XML)") {
+    const int count = count_fds();
+
     osmium::io::Reader reader{with_data_dir("t/io/deleted_nodes.osh"),
                               osmium::osm_entity_bits::node};
     ZeroPositionNodeCountHandler handler;
@@ -164,9 +207,14 @@ TEST_CASE("Reader should decode zero node positions in history (XML)") {
 
     REQUIRE(handler.count == 0);
     REQUIRE(handler.total_count == 2);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should decode zero node positions in history (PBF)") {
+    const int count = count_fds();
+
     osmium::io::Reader reader{with_data_dir("t/io/deleted_nodes.osh.pbf"),
                               osmium::osm_entity_bits::node};
     ZeroPositionNodeCountHandler handler;
@@ -178,30 +226,51 @@ TEST_CASE("Reader should decode zero node positions in history (PBF)") {
 
     REQUIRE(handler.count == 0);
     REQUIRE(handler.total_count == 2);
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should fail with nonexistent file") {
+    const int count = count_fds();
+
     REQUIRE_THROWS(osmium::io::Reader{with_data_dir("t/io/nonexistent-file.osm")});
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should fail with nonexistent file (gz)") {
+    const int count = count_fds();
+
     REQUIRE_THROWS(osmium::io::Reader{with_data_dir("t/io/nonexistent-file.osm.gz")});
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should fail with nonexistent file (pbf)") {
+    const int count = count_fds();
+
     REQUIRE_THROWS(osmium::io::Reader{with_data_dir("t/io/nonexistent-file.osm.pbf")});
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should work when there is an exception in main thread before getting header") {
+    const int count = count_fds();
+
     try {
         osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
         REQUIRE_FALSE(reader.eof());
         throw std::runtime_error{"foo"};
     } catch (...) {
     }
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Reader should work when there is an exception in main thread while reading") {
+    const int count = count_fds();
+
     try {
         osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
         REQUIRE_FALSE(reader.eof());
@@ -209,15 +278,24 @@ TEST_CASE("Reader should work when there is an exception in main thread while re
         throw std::runtime_error{"foo"};
     } catch (...) {
     }
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Applying rvalue handler on reader") {
+    const int count = count_fds();
+
     osmium::io::Reader reader{with_data_dir("t/io/data.osm")};
     struct NullHandler : public osmium::handler::Handler { };
     osmium::apply(reader, NullHandler{});
+
+    reader.close();
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Can call read() exactly once on Reader with entity_bits nothing") {
+    const int count = count_fds();
+
     osmium::io::File file{with_data_dir("t/io/data.osm")};
     osmium::io::Reader reader{file, osmium::osm_entity_bits::nothing};
     REQUIRE_FALSE(reader.eof());
@@ -235,9 +313,13 @@ TEST_CASE("Can call read() exactly once on Reader with entity_bits nothing") {
 
     reader.close();
     REQUIRE(reader.eof());
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Can not read after close") {
+    const int count = count_fds();
+
     osmium::io::File file{with_data_dir("t/io/data.osm")};
     osmium::io::Reader reader{file};
 
@@ -256,5 +338,7 @@ TEST_CASE("Can not read after close") {
     reader.close();
     REQUIRE(reader.eof());
     REQUIRE_THROWS_AS(reader.read(), const osmium::io_error&);
+
+    REQUIRE(count == count_fds());
 }
 
