@@ -34,7 +34,7 @@ static osmium::memory::Buffer get_and_check_buffer() {
 }
 
 TEST_CASE("Writer: Empty writes") {
-    auto buffer = get_and_check_buffer();
+    const int count = count_fds();
 
     std::string filename;
 
@@ -57,9 +57,13 @@ TEST_CASE("Writer: Empty writes") {
     osmium::io::Reader reader_check{filename};
     osmium::memory::Buffer buffer_check = reader_check.read();
     REQUIRE_FALSE(buffer_check);
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Writer: Successful writes writing buffer") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
 
     const auto num = std::distance(buffer.select<osmium::OSMObject>().cbegin(), buffer.select<osmium::OSMObject>().cend());
@@ -71,6 +75,8 @@ TEST_CASE("Writer: Successful writes writing buffer") {
     writer(std::move(buffer));
     writer.close();
 
+    REQUIRE(count == count_fds());
+
     REQUIRE_THROWS_AS(writer(osmium::memory::Buffer{}), const osmium::io_error&);
 
     osmium::io::Reader reader_check{filename};
@@ -82,6 +88,8 @@ TEST_CASE("Writer: Successful writes writing buffer") {
 }
 
 TEST_CASE("Writer: Successful writes writing items") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
 
     const auto num = std::distance(buffer.select<osmium::OSMObject>().cbegin(), buffer.select<osmium::OSMObject>().cend());
@@ -95,6 +103,8 @@ TEST_CASE("Writer: Successful writes writing items") {
     }
     writer.close();
 
+    REQUIRE(count == count_fds());
+
     osmium::io::Reader reader_check{filename};
     const osmium::memory::Buffer buffer_check = reader_check.read();
     REQUIRE(buffer_check);
@@ -104,6 +114,8 @@ TEST_CASE("Writer: Successful writes writing items") {
 }
 
 TEST_CASE("Writer: Successful writes using output iterator") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
 
     const auto num = std::distance(buffer.select<osmium::OSMObject>().cbegin(), buffer.select<osmium::OSMObject>().cend());
@@ -116,6 +128,8 @@ TEST_CASE("Writer: Successful writes using output iterator") {
     std::copy(buffer.cbegin(), buffer.cend(), it);
     writer.close();
 
+    REQUIRE(count == count_fds());
+
     osmium::io::Reader reader_check{filename};
     const osmium::memory::Buffer buffer_check = reader_check.read();
     REQUIRE(buffer_check);
@@ -125,6 +139,8 @@ TEST_CASE("Writer: Successful writes using output iterator") {
 }
 
 TEST_CASE("Writer: Interrupted writer after open") {
+    const int count = count_fds();
+
     auto buffer = get_and_check_buffer();
 
     bool error = false;
@@ -136,9 +152,13 @@ TEST_CASE("Writer: Interrupted writer after open") {
     }
 
     REQUIRE(error);
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Writer: Interrupted writer after write") {
+    const int count = count_fds();
+
     auto buffer = get_and_check_buffer();
 
     bool error = false;
@@ -151,37 +171,55 @@ TEST_CASE("Writer: Interrupted writer after write") {
     }
 
     REQUIRE(error);
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Writer with user-provided pool with default number of threads") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
     osmium::thread::Pool pool;
     osmium::io::Writer writer{"test-writer-pool-with-default-threads.osm", pool, osmium::io::overwrite::allow};
     writer(std::move(buffer));
     writer.close();
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Writer with user-provided pool with negative number of threads") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
     osmium::thread::Pool pool{-2};
     osmium::io::Writer writer{"test-writer-pool-with-negative-threads.osm", pool, osmium::io::overwrite::allow};
     writer(std::move(buffer));
     writer.close();
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Writer with user-provided pool with outlier negative number of threads") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
     osmium::thread::Pool pool{-1000};
     osmium::io::Writer writer{"test-writer-pool-with-outlier-negative-threads.osm", osmium::io::overwrite::allow, pool};
     writer(std::move(buffer));
     writer.close();
+
+    REQUIRE(count == count_fds());
 }
 
 TEST_CASE("Writer with user-provided pool with outlier positive number of threads") {
+    const int count = count_fds();
+
     auto buffer = get_buffer();
     osmium::thread::Pool pool{1000};
     osmium::io::Writer writer{"test-writer-pool-with-outlier-positive-threads.osm", osmium::io::overwrite::allow, pool};
     writer(std::move(buffer));
     writer.close();
+
+    REQUIRE(count == count_fds());
 }
 
