@@ -1,12 +1,12 @@
 #include "catch.hpp"
 
+#include <osmium/util/file.hpp>
+#include <osmium/util/memory_mapping.hpp>
+
 #include <cstdlib>
 #include <limits>
 #include <utility>
 
-#include <osmium/util/file.hpp>
-#include <osmium/util/memory_mapping.hpp>
-
 #if defined(_MSC_VER) || (defined(__GNUC__) && defined(_WIN32))
 #include "win_mkstemp.hpp"
 #endif
@@ -14,7 +14,7 @@
 static const size_t huge = std::numeric_limits<size_t>::max();
 
 TEST_CASE("Anonymous mapping: simple memory mapping should work") {
-    osmium::util::MemoryMapping mapping{1000, osmium::util::MemoryMapping::mapping_mode::write_private};
+    osmium::MemoryMapping mapping{1000, osmium::MemoryMapping::mapping_mode::write_private};
     REQUIRE(mapping.get_addr() != nullptr);
 
     REQUIRE(mapping.size() >= 1000);
@@ -33,22 +33,22 @@ TEST_CASE("Anonymous mapping: simple memory mapping should work") {
 }
 
 TEST_CASE("Anonymous mapping: memory mapping of zero length should result in memory mapping of pagesize length") {
-    osmium::util::MemoryMapping mapping{0, osmium::util::MemoryMapping::mapping_mode::write_private};
-    REQUIRE(mapping.size() == osmium::util::get_pagesize());
+    osmium::MemoryMapping mapping{0, osmium::MemoryMapping::mapping_mode::write_private};
+    REQUIRE(mapping.size() == osmium::get_pagesize());
 }
 
 TEST_CASE("Anonymous mapping: moving a memory mapping should work") {
-    osmium::util::MemoryMapping mapping1{1000, osmium::util::MemoryMapping::mapping_mode::write_private};
-    int* addr1 = mapping1.get_addr<int>();
+    osmium::MemoryMapping mapping1{1000, osmium::MemoryMapping::mapping_mode::write_private};
+    auto* addr1 = mapping1.get_addr<int>();
     *addr1 = 42;
 
     REQUIRE(!!mapping1);
-    osmium::util::MemoryMapping mapping2{std::move(mapping1)};
+    osmium::MemoryMapping mapping2{std::move(mapping1)};
     REQUIRE(!!mapping2);
-    REQUIRE(!mapping1);
+    REQUIRE(!mapping1); // NOLINT(bugprone-use-after-move,misc-use-after-move) okay here, we are checking our own code
     mapping1.unmap();
 
-    int* addr2 = mapping2.get_addr<int>();
+    const auto* addr2 = mapping2.get_addr<int>();
     REQUIRE(*addr2 == 42);
 
     mapping2.unmap();
@@ -56,20 +56,20 @@ TEST_CASE("Anonymous mapping: moving a memory mapping should work") {
 }
 
 TEST_CASE("Anonymous mapping: move assignment should work") {
-    osmium::util::MemoryMapping mapping1{1000, osmium::util::MemoryMapping::mapping_mode::write_private};
-    osmium::util::MemoryMapping mapping2{1000, osmium::util::MemoryMapping::mapping_mode::write_private};
+    osmium::MemoryMapping mapping1{1000, osmium::MemoryMapping::mapping_mode::write_private};
+    osmium::MemoryMapping mapping2{1000, osmium::MemoryMapping::mapping_mode::write_private};
 
     REQUIRE(!!mapping1);
     REQUIRE(!!mapping2);
 
-    int* addr1 = mapping1.get_addr<int>();
+    auto* addr1 = mapping1.get_addr<int>();
     *addr1 = 42;
 
     mapping2 = std::move(mapping1);
     REQUIRE(!!mapping2);
-    REQUIRE(!mapping1);
+    REQUIRE(!mapping1); // NOLINT(bugprone-use-after-move,misc-use-after-move) okay here, we are checking our own code
 
-    int* addr2 = mapping2.get_addr<int>();
+    const auto* addr2 = mapping2.get_addr<int>();
     REQUIRE(*addr2 == 42);
 
     mapping2.unmap();
@@ -78,34 +78,34 @@ TEST_CASE("Anonymous mapping: move assignment should work") {
 
 #ifdef __linux__
 TEST_CASE("Anonymous mapping: remapping to larger size should work") {
-    osmium::util::MemoryMapping mapping{1000, osmium::util::MemoryMapping::mapping_mode::write_private};
+    osmium::MemoryMapping mapping{1000, osmium::MemoryMapping::mapping_mode::write_private};
     REQUIRE(mapping.size() >= 1000);
 
     const size_t size1 = mapping.size();
 
-    int* addr1 = mapping.get_addr<int>();
+    auto* addr1 = mapping.get_addr<int>();
     *addr1 = 42;
 
     mapping.resize(8000);
     REQUIRE(mapping.size() > size1);
 
-    int* addr2 = mapping.get_addr<int>();
+    const auto* addr2 = mapping.get_addr<int>();
     REQUIRE(*addr2 == 42);
 }
 
 TEST_CASE("Anonymous mapping: remapping to smaller size should work") {
-    osmium::util::MemoryMapping mapping{8000, osmium::util::MemoryMapping::mapping_mode::write_private};
+    osmium::MemoryMapping mapping{8000, osmium::MemoryMapping::mapping_mode::write_private};
     REQUIRE(mapping.size() >= 1000);
 
     const size_t size1 = mapping.size();
 
-    int* addr1 = mapping.get_addr<int>();
+    auto* addr1 = mapping.get_addr<int>();
     *addr1 = 42;
 
     mapping.resize(500);
     REQUIRE(mapping.size() < size1);
 
-    int* addr2 = mapping.get_addr<int>();
+    const auto* addr2 = mapping.get_addr<int>();
     REQUIRE(*addr2 == 42);
 }
 #endif
@@ -115,10 +115,10 @@ TEST_CASE("File-based mapping: writing to a mapped file should work") {
     const int fd = mkstemp(filename);
     REQUIRE(fd > 0);
 
-    osmium::util::resize_file(fd, 100);
+    osmium::resize_file(fd, 100);
 
     {
-        osmium::util::MemoryMapping mapping{100, osmium::util::MemoryMapping::mapping_mode::write_shared, fd};
+        osmium::MemoryMapping mapping{100, osmium::MemoryMapping::mapping_mode::write_shared, fd};
         REQUIRE(mapping.writable());
 
         REQUIRE(!!mapping);
@@ -129,11 +129,11 @@ TEST_CASE("File-based mapping: writing to a mapped file should work") {
         mapping.unmap();
     }
 
-    REQUIRE(osmium::util::file_size(fd) == 100);
+    REQUIRE(osmium::file_size(fd) == 100);
 
     {
-        osmium::util::MemoryMapping mapping{100, osmium::util::MemoryMapping::mapping_mode::readonly, fd};
-        REQUIRE(!mapping.writable());
+        osmium::MemoryMapping mapping{100, osmium::MemoryMapping::mapping_mode::readonly, fd};
+        REQUIRE_FALSE(mapping.writable());
 
         REQUIRE(!!mapping);
         REQUIRE(mapping.size() >= 100);
@@ -152,7 +152,7 @@ TEST_CASE("File-based mapping: Reading from a zero-sized mapped file should work
     REQUIRE(fd > 0);
 
     {
-        osmium::util::MemoryMapping mapping{0, osmium::util::MemoryMapping::mapping_mode::readonly, fd};
+        osmium::MemoryMapping mapping{0, osmium::MemoryMapping::mapping_mode::readonly, fd};
         REQUIRE(mapping.size() > 0);
         mapping.unmap();
     }
@@ -166,10 +166,10 @@ TEST_CASE("File-based mapping: writing to a privately mapped file should work")
     const int fd = mkstemp(filename);
     REQUIRE(fd > 0);
 
-    osmium::util::resize_file(fd, 100);
+    osmium::resize_file(fd, 100);
 
     {
-        osmium::util::MemoryMapping mapping{100, osmium::util::MemoryMapping::mapping_mode::write_private, fd};
+        osmium::MemoryMapping mapping{100, osmium::MemoryMapping::mapping_mode::write_private, fd};
         REQUIRE(mapping.writable());
 
         REQUIRE(!!mapping);
@@ -180,11 +180,11 @@ TEST_CASE("File-based mapping: writing to a privately mapped file should work")
         mapping.unmap();
     }
 
-    REQUIRE(osmium::util::file_size(fd) == 100);
+    REQUIRE(osmium::file_size(fd) == 100);
 
     {
-        osmium::util::MemoryMapping mapping{100, osmium::util::MemoryMapping::mapping_mode::readonly, fd};
-        REQUIRE(!mapping.writable());
+        osmium::MemoryMapping mapping{100, osmium::MemoryMapping::mapping_mode::readonly, fd};
+        REQUIRE_FALSE(mapping.writable());
 
         REQUIRE(!!mapping);
         REQUIRE(mapping.size() >= 100);
@@ -202,18 +202,18 @@ TEST_CASE("File-based mapping: remapping to larger size should work") {
     const int fd = mkstemp(filename);
     REQUIRE(fd > 0);
 
-    osmium::util::MemoryMapping mapping{100, osmium::util::MemoryMapping::mapping_mode::write_shared, fd};
+    osmium::MemoryMapping mapping{100, osmium::MemoryMapping::mapping_mode::write_shared, fd};
     REQUIRE(mapping.size() >= 100);
     const size_t size1 = mapping.size();
 
-    int* addr1 = mapping.get_addr<int>();
+    auto* addr1 = mapping.get_addr<int>();
     *addr1 = 42;
 
     mapping.resize(8000);
     REQUIRE(mapping.size() >= 8000);
     REQUIRE(mapping.size() > size1);
 
-    int* addr2 = mapping.get_addr<int>();
+    const auto* addr2 = mapping.get_addr<int>();
     REQUIRE(*addr2 == 42);
 
     mapping.unmap();
@@ -228,18 +228,18 @@ TEST_CASE("File-based mapping: remapping to smaller size should work") {
     REQUIRE(fd > 0);
 
     {
-        osmium::util::MemoryMapping mapping{8000, osmium::util::MemoryMapping::mapping_mode::write_shared, fd};
+        osmium::MemoryMapping mapping{8000, osmium::MemoryMapping::mapping_mode::write_shared, fd};
         REQUIRE(mapping.size() >= 8000);
         const size_t size1 = mapping.size();
 
-        int* addr1 = mapping.get_addr<int>();
+        auto* addr1 = mapping.get_addr<int>();
         *addr1 = 42;
 
         mapping.resize(50);
         REQUIRE(mapping.size() >= 50);
         REQUIRE(mapping.size() < size1);
 
-        int* addr2 = mapping.get_addr<int>();
+        const auto* addr2 = mapping.get_addr<int>();
         REQUIRE(*addr2 == 42);
     }
 
@@ -248,7 +248,7 @@ TEST_CASE("File-based mapping: remapping to smaller size should work") {
 }
 
 TEST_CASE("Typed anonymous mapping: simple memory mapping should work") {
-    osmium::util::TypedMemoryMapping<uint32_t> mapping{1000};
+    osmium::TypedMemoryMapping<uint32_t> mapping{1000};
     volatile uint32_t* addr = mapping.begin();
 
     REQUIRE(mapping.writable());
@@ -263,14 +263,14 @@ TEST_CASE("Typed anonymous mapping: simple memory mapping should work") {
 }
 
 TEST_CASE("Typed anonymous mapping: moving a memory mapping should work") {
-    osmium::util::TypedMemoryMapping<uint32_t> mapping1{1000};
+    osmium::TypedMemoryMapping<uint32_t> mapping1{1000};
     uint32_t* addr1 = mapping1.begin();
     *addr1 = 42;
 
     REQUIRE(!!mapping1);
-    osmium::util::TypedMemoryMapping<uint32_t> mapping2{std::move(mapping1)};
+    osmium::TypedMemoryMapping<uint32_t> mapping2{std::move(mapping1)};
     REQUIRE(!!mapping2);
-    REQUIRE(!mapping1);
+    REQUIRE(!mapping1); // NOLINT(bugprone-use-after-move,misc-use-after-move) okay here, we are checking our own code
     mapping1.unmap();
 
     const auto addr2 = mapping2.begin();
@@ -281,8 +281,8 @@ TEST_CASE("Typed anonymous mapping: moving a memory mapping should work") {
 }
 
 TEST_CASE("Typed anonymous mapping: move assignment should work") {
-    osmium::util::TypedMemoryMapping<uint32_t> mapping1{1000};
-    osmium::util::TypedMemoryMapping<uint32_t> mapping2{1000};
+    osmium::TypedMemoryMapping<uint32_t> mapping1{1000};
+    osmium::TypedMemoryMapping<uint32_t> mapping2{1000};
 
     REQUIRE(!!mapping1);
     REQUIRE(!!mapping2);
@@ -292,7 +292,7 @@ TEST_CASE("Typed anonymous mapping: move assignment should work") {
 
     mapping2 = std::move(mapping1);
     REQUIRE(!!mapping2);
-    REQUIRE(!mapping1);
+    REQUIRE(!mapping1); // NOLINT(bugprone-use-after-move,misc-use-after-move) okay here, we are checking our own code
 
     const auto addr2 = mapping2.begin();
     REQUIRE(*addr2 == 42);
@@ -303,7 +303,7 @@ TEST_CASE("Typed anonymous mapping: move assignment should work") {
 
 #ifdef __linux__
 TEST_CASE("Typed anonymous mapping: remapping to larger size should work") {
-    osmium::util::TypedMemoryMapping<uint32_t> mapping{1000};
+    osmium::TypedMemoryMapping<uint32_t> mapping{1000};
     REQUIRE(mapping.size() >= 1000);
 
     auto addr1 = mapping.begin();
@@ -316,7 +316,7 @@ TEST_CASE("Typed anonymous mapping: remapping to larger size should work") {
 }
 
 TEST_CASE("Typed anonymous mapping: remapping to smaller size should work") {
-    osmium::util::TypedMemoryMapping<uint32_t> mapping{8000};
+    osmium::TypedMemoryMapping<uint32_t> mapping{8000};
     REQUIRE(mapping.size() >= 8000);
 
     auto addr1 = mapping.begin();
@@ -334,10 +334,10 @@ TEST_CASE("Typed file-based mapping: writing to a mapped file should work") {
     const int fd = mkstemp(filename);
     REQUIRE(fd > 0);
 
-    osmium::util::resize_file(fd, 100);
+    osmium::resize_file(fd, 100);
 
     {
-        osmium::util::TypedMemoryMapping<uint32_t> mapping{100, osmium::util::MemoryMapping::mapping_mode::write_shared, fd};
+        osmium::TypedMemoryMapping<uint32_t> mapping{100, osmium::MemoryMapping::mapping_mode::write_shared, fd};
         REQUIRE(mapping.writable());
 
         REQUIRE(!!mapping);
@@ -349,8 +349,8 @@ TEST_CASE("Typed file-based mapping: writing to a mapped file should work") {
     }
 
     {
-        osmium::util::TypedMemoryMapping<uint32_t> mapping{100, osmium::util::MemoryMapping::mapping_mode::readonly, fd};
-        REQUIRE(!mapping.writable());
+        osmium::TypedMemoryMapping<uint32_t> mapping{100, osmium::MemoryMapping::mapping_mode::readonly, fd};
+        REQUIRE_FALSE(mapping.writable());
 
         REQUIRE(!!mapping);
         REQUIRE(mapping.size() >= 100);
@@ -364,7 +364,7 @@ TEST_CASE("Typed file-based mapping: writing to a mapped file should work") {
 }
 
 TEST_CASE("Anonymous memory mapping class: simple memory mapping should work") {
-    osmium::util::AnonymousMemoryMapping mapping{1000};
+    osmium::AnonymousMemoryMapping mapping{1000};
     REQUIRE(mapping.get_addr() != nullptr);
 
     volatile int* addr = mapping.get_addr<int>();
@@ -382,28 +382,28 @@ TEST_CASE("Anonymous memory mapping class: simple memory mapping should work") {
 
 #ifdef __linux__
 TEST_CASE("Anonymous memory mapping class: remapping to larger size should work") {
-    osmium::util::AnonymousMemoryMapping mapping{1000};
+    osmium::AnonymousMemoryMapping mapping{1000};
     REQUIRE(mapping.size() >= 1000);
 
-    int* addr1 = mapping.get_addr<int>();
+    auto* addr1 = mapping.get_addr<int>();
     *addr1 = 42;
 
     mapping.resize(2000);
 
-    const int* addr2 = mapping.get_addr<int>();
+    const auto* addr2 = mapping.get_addr<int>();
     REQUIRE(*addr2 == 42);
 }
 
 TEST_CASE("Anonymous memory mapping class: remapping to smaller size should work") {
-    osmium::util::AnonymousMemoryMapping mapping{2000};
+    osmium::AnonymousMemoryMapping mapping{2000};
     REQUIRE(mapping.size() >= 2000);
 
-    int* addr1 = mapping.get_addr<int>();
+    auto* addr1 = mapping.get_addr<int>();
     *addr1 = 42;
 
     mapping.resize(500);
 
-    const int* addr2 = mapping.get_addr<int>();
+    const auto* addr2 = mapping.get_addr<int>();
     REQUIRE(*addr2 == 42);
 }
 #endif
